# Flow

[![PyPI version](https://badge.fury.io/py/sysflow.svg)](https://badge.fury.io/py/sysflow)


Flow that exists as an aid to saving time for research.



## Installation

Install the newest version by

```bash
pip install -U git+https://github.com/JiahaoYao/Flow.git@master
```

